@@ -35,6 +35,9 @@ FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
 # 请求role信息失败。
 FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 
+# CopyAsyncRun 传参异常。
+FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
+
 # 复制函数失败。
 FAILEDOPERATION_COPYFAILED = 'FailedOperation.CopyFailed'
 
@@ -92,6 +95,9 @@ FAILEDOPERATION_GETALIAS = 'FailedOperation.GetAlias'
 # 获取函数代码地址失败。
 FAILEDOPERATION_GETFUNCTIONADDRESS = 'FailedOperation.GetFunctionAddress'
 
+# InstanceNotFound 实例不存在。
+FAILEDOPERATION_INSTANCENOTFOUND = 'FailedOperation.InstanceNotFound'
+
 # 当前账号或命名空间处于欠费状态，请在可用时重试。
 FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 
@@ -113,6 +119,12 @@ FAILEDOPERATION_PROVISIONCREATETIMER = 'FailedOperation.ProvisionCreateTimer'
 # 删除定时预置任务失败。
 FAILEDOPERATION_PROVISIONDELETETIMER = 'FailedOperation.ProvisionDeleteTimer'
 
+# 预置超过可用。
+FAILEDOPERATION_PROVISIONEDEXCEEDAVAILABLE = 'FailedOperation.ProvisionedExceedAvailable'
+
+# 预置超限。
+FAILEDOPERATION_PROVISIONEDEXCEEDRESERVED = 'FailedOperation.ProvisionedExceedReserved'
+
 # 当前函数版本已有预置任务处于进行中，请稍后重试。
 FAILEDOPERATION_PROVISIONEDINPROGRESS = 'FailedOperation.ProvisionedInProgress'
 
@@ -125,9 +137,15 @@ FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 # 角色不存在。
 FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
 
+# ReservedExceedTotal 总保留超限。
+FAILEDOPERATION_RESERVEDEXCEEDTOTAL = 'FailedOperation.ReservedExceedTotal'
+
 # 当前函数已有保留并发设置任务处于进行中，请稍后重试。
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
+# ServiceClosed 请确认后再操作。
+FAILEDOPERATION_SERVICECLOSED = 'FailedOperation.ServiceClosed'
+
 # Topic不存在。
 FAILEDOPERATION_TOPICNOTEXIST = 'FailedOperation.TopicNotExist'
 
@@ -176,12 +194,24 @@ INTERNALERROR_SYSTEM = 'InternalError.System'
 # 内部服务错误。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
+# 日志参数有误。
+INVALIDPARAMETER_CLS = 'InvalidParameter.Cls'
+
 # FunctionName取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETER_FUNCTIONNAME = 'InvalidParameter.FunctionName'
 
+# 创建函数传参异常。
+INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
+
 # 请求参数不合法。
 INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 
+# 请求大小超限。
+INVALIDPARAMETER_REQUESTTOOLARGE = 'InvalidParameter.RequestTooLarge'
+
+# RoleCheck 传参有误。
+INVALIDPARAMETER_ROLECHECK = 'InvalidParameter.RoleCheck'
+
 # RoutingConfig参数传入错误。
 INVALIDPARAMETER_ROUTINGCONFIG = 'InvalidParameter.RoutingConfig'
 
@@ -272,6 +302,9 @@ INVALIDPARAMETERVALUE_COSBUCKETNAME = 'InvalidParameterValue.CosBucketName'
 # CosBucketRegion取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETERVALUE_COSBUCKETREGION = 'InvalidParameterValue.CosBucketRegion'
 
+# COS通知规则冲突。
+INVALIDPARAMETERVALUE_COSNOTIFYRULECONFLICT = 'InvalidParameterValue.CosNotifyRuleConflict'
+
 # CosObjectName不符合规范。
 INVALIDPARAMETERVALUE_COSOBJECTNAME = 'InvalidParameterValue.CosObjectName'
 
@@ -326,6 +359,12 @@ INVALIDPARAMETERVALUE_FUNCTION = 'InvalidParameterValue.Function'
 # 函数不存在。
 INVALIDPARAMETERVALUE_FUNCTIONNAME = 'InvalidParameterValue.FunctionName'
 
+# 请求 id 传参错误。
+INVALIDPARAMETERVALUE_FUNCTIONREQUESTID = 'InvalidParameterValue.FunctionRequestId'
+
+# FunctionType参数错误。
+INVALIDPARAMETERVALUE_FUNCTIONTYPE = 'InvalidParameterValue.FunctionType'
+
 # GitBranch不符合规范。
 INVALIDPARAMETERVALUE_GITBRANCH = 'InvalidParameterValue.GitBranch'
 
@@ -338,18 +377,27 @@ INVALIDPARAMETERVALUE_GITDIRECTORY = 'InvalidParameterValue.GitDirectory'
 # GitPassword不符合规范。
 INVALIDPARAMETERVALUE_GITPASSWORD = 'InvalidParameterValue.GitPassword'
 
+# GitPasswordSecret 传参有误。
+INVALIDPARAMETERVALUE_GITPASSWORDSECRET = 'InvalidParameterValue.GitPasswordSecret'
+
 # GitUrl不符合规范。
 INVALIDPARAMETERVALUE_GITURL = 'InvalidParameterValue.GitUrl'
 
 # GitUserName不符合规范。
 INVALIDPARAMETERVALUE_GITUSERNAME = 'InvalidParameterValue.GitUserName'
 
+# GitUserNameSecret 传参有误。
+INVALIDPARAMETERVALUE_GITUSERNAMESECRET = 'InvalidParameterValue.GitUserNameSecret'
+
 # Handler传入错误。
 INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 
 # IdleTimeOut参数传入错误。
 INVALIDPARAMETERVALUE_IDLETIMEOUT = 'InvalidParameterValue.IdleTimeOut'
 
+# ImageType 参数值有误。
+INVALIDPARAMETERVALUE_IMAGETYPE = 'InvalidParameterValue.ImageType'
+
 # imageUri 传入有误。
 INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
 
@@ -521,6 +569,9 @@ LIMITEXCEEDED_ALIAS = 'LimitExceeded.Alias'
 # Cdn使用超过最大限制。
 LIMITEXCEEDED_CDN = 'LimitExceeded.Cdn'
 
+# 用户开启镜像加速函数版本超限。
+LIMITEXCEEDED_CONTAINERIMAGEACCELERATEQUOTA = 'LimitExceeded.ContainerImageAccelerateQuota'
+
 # eip资源超限。
 LIMITEXCEEDED_EIP = 'LimitExceeded.Eip'
 
@@ -551,6 +602,9 @@ LIMITEXCEEDED_LAYERVERSIONS = 'LimitExceeded.LayerVersions'
 # layer数量超出最大限制。
 LIMITEXCEEDED_LAYERS = 'LimitExceeded.Layers'
 
+# 动态扩容最大值超限。
+LIMITEXCEEDED_MAXCAPACITY = 'LimitExceeded.MaxCapacity'
+
 # 内存超出最大限制。
 LIMITEXCEEDED_MEMORY = 'LimitExceeded.Memory'
 
@@ -596,6 +650,9 @@ MISSINGPARAMETER_CODE = 'MissingParameter.Code'
 # 缺失 Runtime 字段。
 MISSINGPARAMETER_RUNTIME = 'MissingParameter.Runtime'
 
+# 账号已被隔离。
+OPERATIONDENIED_ACCOUNTISOLATE = 'OperationDenied.AccountIsolate'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -647,6 +704,9 @@ RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 # 指定的cfs下未找到您所指定的挂载点。
 RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
 
+# CfsProtocolError 参数异常。
+RESOURCENOTFOUND_CFSPROTOCOLERROR = 'ResourceNotFound.CfsProtocolError'
+
 # 检测cfs状态为不可用。
 RESOURCENOTFOUND_CFSSTATUSERROR = 'ResourceNotFound.CfsStatusError'
 
@@ -773,6 +833,9 @@ UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 # 指定的配置EipFixed暂不支持。
 UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
 
+# 不支持的地域。
+UNSUPPORTEDOPERATION_NOTSUPPORTREGION = 'UnsupportedOperation.NotSupportRegion'
+
 # 不支持此地域。
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
